@@ -127,6 +127,17 @@ class ControllerMixin(object):
         elif file_path.endswith('.tac'):
             document.set_language(lang_manager.get_language('python'))
 
+    def show_info_dialog(self, message):
+        use_fake_gedit = os.environ.get('use_fake_gedit') == 'true'
+        if use_fake_gedit:
+            self._message = message
+            return
+        dialog = Gtk.MessageDialog(
+            self.window, 0, Gtk.MessageType.INFO, Gtk.ButtonsType.CLOSE,
+            message)
+        dialog.run()
+        dialog.destroy()
+
 
 def set_file_line(column, cell, model, piter, cell_type):
     """Set the value as file or line information."""
