@@ -590,7 +590,11 @@ class PythonGenerator(BaseGenerator):
             return is_authoritative, []
 
         for symbol in namespaces[1:]:
-            module_ = getattr(module_, symbol)
+            next_module = getattr(module_, symbol, None)
+            if next_module is not None:
+                module_ = next_module
+            else:
+                break
         is_authoritative = True
         symbols = [self._get_dynamic_proposal(module_, name)
                    for name in dir(module_) if name.startswith(prefix)]
