@@ -21,9 +21,11 @@ import sys
 import threading
 from optparse import OptionParser
 
-from gi.repository import GObject
-from gi.repository import Gdk
-from gi.repository import Gtk
+from gi.repository import (
+    GObject,
+    Gdk,
+    Gtk,
+    )
 
 from gdp import (
     config,
@@ -32,6 +34,9 @@ from gdp import (
     )
 
 
+GObject.threads_init()
+
+
 find_params = namedtuple(
     'FindParams', ['path', 'pattern', 'is_re', 'is_case', 'file_pattern'])
 
@@ -98,6 +103,7 @@ def extract_match(file_path, match_re, substitution=None):
 class FinderWorker(threading.Thread):
 
     def __init__(self, treestore, find_params, callback, substitution=None):
+        super(FinderWorker, self).__init__()
         self.treestore = treestore
         self.find_params = find_params
         self.callback = callback
@@ -113,6 +119,18 @@ class FinderWorker(threading.Thread):
             pattern = '(?i)%s' % pattern
         return pattern
 
+    def append_match(self, piter, file_path, icon, lineno, text, path):
+        self.treestore.append(piter, (file_path, icon, lineno, text, path))
+        return False
+
+    def idle_append_match(self, piter, file_path, icon, lineno, text, path):
+        GObject.idle_add(
+            self.append_match, piter, file_path, icon, lineno, text, path)
+
+    def start(self):
+        super(FinderWorker, self).start()
+        return False
+
     def run(self):
         try:
             for summary in find_matches(
@@ -131,17 +149,17 @@ class FinderWorker(threading.Thread):
                 else:
                     icon = 'edit-find-replace'  # Gtk.STOCK_FIND_AND_REPLACE
                 for line in summary['lines']:
-                    self.treestore.append(piter,
-                        (file_path, icon, line['lineno'], line['text'],
-                         self.find_params.path))
+                    self.idle_append_match(
+                        piter, file_path, icon, line['lineno'], line['text'],
+                        self.find_params.path)
             if self.treestore.get_iter_first() is None:
                 message = 'No matches found'
-                self.treestore.append(
-                    None, (message, 'stock_dialog-info', 0, None, None))
+                self.idle_append_match(
+                    None, message, 'stock_dialog-info', 0, None, None)
         except sre_constants.error, e:
             message = 'Find could not be run: %s' % str(e)
-            self.treestore.append(
-                None, (message, 'stock_dialog-info', 0, None, None))
+            self.idle_append_match(
+                None, message, 'stock_dialog-info', 0, None, None)
         self.callback()
 
 
@@ -317,7 +335,9 @@ class Finder(ControllerMixin):
             'Matches for [%s]' % pattern)
         find_worker = FinderWorker(
             treestore, find_params, self.on_find_complete, substitution)
-        find_worker.run()
+        # Queue the find worker after the events emited at the top
+        # of this method.
+        GObject.idle_add(find_worker.start)
 
     def on_find_complete(self):
         if self.path_comboentry.get_active_text() == self.CURRENT_FILE:
