@@ -18,12 +18,19 @@ from testing import GeditTestCase
 
 class TestCallback:
 
-    def __init__(self):
+    def __init__(self, func=None):
         self.called = False
+        if func is None:
+            func = self.on_callback
+        self.func = func
 
     def on_callback(self):
         self.called = True
 
+    def __call__(self):
+        self.func()
+        self.on_callback()
+
 
 class FinderWorkerTestCase(GeditTestCase):
 
@@ -64,6 +71,34 @@ class FinderWorkerTestCase(GeditTestCase):
         worker = FinderWorker(treestore, params, callback)
         self.assertEqual('Snark\\(', worker.pattern)
 
+    def test_append_match(self):
+        params = find_params('./', 'snark', False, False, None)
+        treestore = self.makeTreeStore()
+        callback = TestCallback()
+        worker = FinderWorker(treestore, params, callback)
+        result = worker.append_match(
+            None, 'hello', 'stock_dialog-info', 0, None, None)
+        self.assertIs(False, result)
+        self.assertEqual('hello', worker.treestore[0][0])
+
+    def test_run(self):
+        params = find_params('./', 'snark', False, False, None)
+        treestore = self.makeTreeStore()
+        callback = TestCallback()
+        worker = FinderWorker(treestore, params, callback)
+        worker.run()
+        self.assertIs(True, callback.called)
+
+    def test_start(self):
+        params = find_params('./', 'snark', False, False, None)
+        treestore = self.makeTreeStore()
+        callback = TestCallback()
+        worker = FinderWorker(treestore, params, callback)
+        result = worker.start()
+        self.assertIs(False, result)
+        worker.join()
+        self.assertIs(True, callback.called)
+
 
 class FinderTestCase(GeditTestCase):
 
