@@ -5,9 +5,12 @@
 
 __all__ = [
     'Dummy',
+    'FakeMethod',
     'GeditTestCase',
     'SignalTester',
     'make_gedit',
+    'MockMethod'
+    'MockProperty',
     'literal',
     'proof',
     ]
@@ -71,6 +74,75 @@ class GeditTestCase(unittest.TestCase):
         return text_file
 
 
+class MockMethod:
+
+    @classmethod
+    def bind(klass, test_instance, obj, method_name,
+             return_value=None, raise_error=None, raise_on=1):
+        original_method = getattr(obj, method_name)
+        test_instance.addCleanup(setattr, obj, method_name, original_method)
+        setattr(obj, method_name, klass(return_value, raise_error, raise_on))
+
+    def __init__(self, return_value=None, raise_error=None, raise_on=1):
+        self.called = False
+        self.call_count = 0
+        self.args = None
+        self.kwargs = None
+        self.return_value = return_value
+        self.raise_error = raise_error
+        self.raise_on = raise_on
+
+    def __call__(self, *args, **kwargs):
+        self.called = True
+        self.call_count += 1
+        self.args = args
+        self.kwargs = kwargs
+        if self.raise_error is not None and self.call_count == self.raise_on:
+            raise self.raise_error
+        return self.return_value
+
+
+class FakeMethod(MockMethod):
+
+    @classmethod
+    def bind(klass, test_instance, obj, method_name, function):
+        original_method = getattr(obj, method_name)
+        test_instance.addCleanup(setattr, obj, method_name, original_method)
+        setattr(obj, method_name, klass(function))
+
+    def __init__(self, function=None):
+        super(FakeMethod, self).__init__()
+        if function is None:
+            function = self.no_def
+        self.function = function
+
+    def __call__(self, *args, **kwargs):
+        super(FakeMethod, self).__call__(*args, **kwargs)
+        self.function()
+
+    def no_def(self):
+        return None
+
+
+class MockProperty(MockMethod):
+
+    @classmethod
+    def bind(klass, test_instance, obj, method_name, return_value=None):
+        original_method = getattr(obj, method_name)
+        test_instance.addCleanup(setattr, obj, method_name, original_method)
+        mock = klass(return_value)
+        setattr(obj, method_name, property(mock.get_value, mock.set_value))
+        return mock
+
+    def get_value(self, other):
+        self.called = True
+        return self.return_value
+
+    def set_value(self, other, value):
+        self.called = True
+        self.return_value = value
+
+
 class Dummy(object):
     """A class for passing dummy data between the test and the testee."""
 
