@@ -132,7 +132,7 @@ def setup_env(params=None):
     """
     Env.dir_re = re.compile(params.get('dir_re', '(sourcecode)'))
     if 'paths' in params:
-        [sys.path.append(os.path.abspath(path)) for path in params['paths']]
+        [sys.path.insert(0, os.path.abspath(path)) for path in params['paths']]
     if 'verbosity' in params:
         Env.verbosity = params['verbosity']
 
